pub struct QRMatrix {
pub version: u8,
pub size: usize,
pub modules: Vec<Vec<Module>>,
}Expand description
The QR module matrix.
Fields
version: u8size: usizemodules: Vec<Vec<Module>>Implementations
Sourceimpl QRMatrix
impl QRMatrix
Sourcepub fn new(version: u8) -> Self
pub fn new(version: u8) -> Self
Create a new empty matrix for the given version. All modules start as Data(false).
Sourcepub fn data_at(&self, i: usize, j: usize) -> Option<bool>
pub fn data_at(&self, i: usize, j: usize) -> Option<bool>
Get the boolean value at (i, j) for data modules.
Sourcepub fn place_function_patterns(&mut self)
pub fn place_function_patterns(&mut self)
Place all function patterns for this version, plus reserve the format-info (and, for v ≥ 7, version-info) areas so that data placement skips over them.